
# Formulas

Adds a `formula/2` predicate for each formula present in the encoding with respect to the types defined in the  [syntax](./syntax.md).

::: src/metasp/encodings/formulas.lp
    handler: asp
    options:
        glossary:
            include_references: false
        predicate_table: true
        encodings:
            git_link: true
        start_level: 1
